# wellwiz


[![image](https://img.shields.io/pypi/v/wellwiz.svg)](https://pypi.python.org/pypi/wellwiz)
[![image](https://img.shields.io/conda/vn/conda-forge/wellwiz.svg)](https://anaconda.org/conda-forge/wellwiz)


**A developing python package to gather information about the gas and oil wells and know the risk through a map visualization.**


-   Free software: MIT License
-   Documentation: https://OmiimO05.github.io/wellwiz

![](https://i.gifer.com/GG4X.gif)
    

## Features

-   To visualize the oil and gas wells in Knoxville, TN.
-   To know their names and purpose.
-   To identify the risk of fracking exposure.


## Demo code
For the demonstration you can visit- 
[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/OmIImO05/netpanda/blob/main/docs/examples/example_code.ipynb)

or you can also watch this video. 


Thank you for interest!
